@@ -672,6 +672,7 @@ class Django12Schema(Django11Schema):
                 'password': StringOption(),
                 'host': StringOption(),
                 'port': StringOption(),
+                'options': DictOption(),
             }),
             default={
                 'default': {
@@ -681,6 +682,7 @@ class Django12Schema(Django11Schema):
                     'PASSWORD': '',
                     'HOST': '',
                     'PORT': '',
+                    'OPTIONS': {},
                 }
             })
         database_routers = ListOption(
@@ -1163,7 +1165,8 @@ class Django14Schema(Django14Base):
 
         wsgi_application = StringOption(
             help="The full Python path of the WSGI application object"
-                 "that Django's built-in servers (e.g. runserver) will use.")
+                 "that Django's built-in servers (e.g. runserver) will use.",
+            null=True)
 
         csrf_cookie_secure = BoolOption(
             default=False,
@@ -1659,6 +1662,67 @@ class Django15Schema(Django15Base):
                 ])
 
 
+class Django153Schema(Django15Schema):
+    version = '1.5.3'
+
+    class django(Django15Schema.django):
+        # XXX: even though the Django documentation says PickleSerializer is
+        # the default value, it's not the case with a vanilla 1.5.3 project
+        session_serializer = StringOption(
+            default='django.contrib.sessions.serializers.JSONSerializer',
+            help="Full import path of a serializer class to use for "
+                 "serializing session data.")
+
+
+Django16Base = derivate_django_schema(
+    Django153Schema)
+
+
+class Django16Schema(Django16Base):
+    version = '1.6'
+
+    class django(Django16Base.django):
+
+        base_dir = StringOption(
+            help="Used by the example project to help build paths for other "
+                 "settings variables.")
+
+        databases = DictOption(
+            item=UpperCaseDictOption(spec={
+                'engine': StringOption(default='django.db.backends.'),
+                'name': StringOption(),
+                'user': StringOption(),
+                'password': StringOption(),
+                'host': StringOption(),
+                'port': StringOption(),
+                'atomic_requests': BoolOption(default=False),
+                'autocommit': BoolOption(default=True),
+                'conn_max_age': IntOption(default=0),
+            }),
+            default={
+                'default': {
+                    'ENGINE': 'django.db.backends.',
+                    'NAME': '',
+                    'USER': '',
+                    'PASSWORD': '',
+                    'HOST': '',
+                    'PORT': '',
+                }
+            })
+
+        csrf_cookie_httponly = BoolOption(
+            default=False,
+            help="Whether to use HttpOnly flag on the CSRF cookie. If this "
+                 "is set to True, client-side JavaScript will not to be able "
+                 "to access the CSRF cookie. See SESSION_COOKIE_HTTPONLY for "
+                 "details on HttpOnly.")
+
+        session_serializer = StringOption(
+            default='django.contrib.sessions.serializers.JSONSerializer',
+            help="Full import path of a serializer class to use for "
+                 "serializing session data.")
+
+
 class DjangoSchemaFactory(object):
     def __init__(self):
         self._schemas = {}
@@ -1791,5 +1855,10 @@ schemas.register(Django136Schema, '1.3.7')
 schemas.register(Django14Schema)
 schemas.register(Django144Schema)
 schemas.register(Django145Schema)
+schemas.register(Django145Schema, '1.4.8')
 schemas.register(Django15Schema)
 schemas.register(Django15Schema, '1.5.1')
+schemas.register(Django15Schema, '1.5.2')
+schemas.register(Django153Schema)
+schemas.register(Django153Schema, '1.5.4')
+schemas.register(Django16Schema)
