@@ -27,7 +27,7 @@ from django.conf import settings
 from django.conf import global_settings
 from mock import patch
 
-from django_configglue.management import GlueManagementUtility, LaxOptionParser
+from django_configglue import management
 from django_configglue.utils import (
     SETTINGS_ENCODING,
     configglue,
@@ -342,7 +342,7 @@ class GlueManagementUtilityTestCase(ConfigGlueDjangoCommandTestCase):
     def setUp(self):
         super(GlueManagementUtilityTestCase, self).setUp()
 
-        self.util = GlueManagementUtility()
+        self.util = management.GlueManagementUtility()
 
     def execute(self):
         self.begin_capture()
@@ -433,7 +433,7 @@ class GlueManagementUtilityTestCase(ConfigGlueDjangoCommandTestCase):
 class LaxOptionParserTestCase(TestCase):
 
     def test_explicit_value_for_unknown_option(self):
-        parser = LaxOptionParser()
+        parser = management.LaxOptionParser()
         rargs = ["--foo=bar"]
         self.assertRaises(BadOptionError, parser._process_long_opt, rargs, [])
         self.assertEqual([], rargs)
@@ -456,3 +456,27 @@ class UpperCaseDictOptionTestCase(TestCase):
         result = schema.foo.parse('mydict', parser)
 
         self.assertEqual(result, {'BAR': '42'})
+
+
+class ManagementTestCase(TestCase):
+    def test_django_13_management_utility(self):
+        with patch.object(django, 'VERSION', (1, 3)):
+            # force reloading of module
+            reload(management)
+
+            self.assertEqual(management.management.ManagementUtility,
+                             management.GlueManagementUtility)
+
+    def test_django_14_management_utility(self):
+        with patch.object(django, 'VERSION', (1, 4)):
+            # force reloading of module
+            reload(management)
+
+            self.assertEqual(management.management.ManagementUtility,
+                             django.core.management.ManagementUtility)
+
+    def test_execute_from_command_line(self):
+        name = 'django_configglue.management.GlueManagementUtility'
+        with patch(name) as mock_utility:
+            management.execute_from_command_line()
+            mock_utility.assert_called_once_with(None)
