@@ -6,10 +6,11 @@ import os.path
 import django
 from django import get_version
 from django.conf import settings
-from django.core.management import ManagementUtility, CommandError
+from django.core.management import CommandError
 
 from mock import patch, Mock
 
+from django_configglue.management import GlueManagementUtility
 from django_configglue.utils import SETTINGS_ENCODING
 from django_configglue.schema import schemas
 from django_configglue.tests.helpers import (
@@ -42,6 +43,10 @@ class SettingsCommandTestCase(ConfigGlueDjangoCommandTestCase):
             "ROOT_URLCONF = 'urls'",
             "SETTINGS_ENCODING = '%s'" % SETTINGS_ENCODING,
         ]
+        # Django 1.6 needs special treatment (BASE_DIR is not a core setting,
+        # but it's a very useful convention from the example project)
+        if django.VERSION >= (1, 6, 0):
+            expected_values.append("BASE_DIR = ''")
         self.call_command(show_current=True)
         output_lines = self.output.strip().split('\n')
         self.assertEqual(set(expected_values), set(output_lines))
@@ -197,7 +202,7 @@ class CommandLineIntegrationTestCase(ConfigGlueDjangoCommandTestCase):
     def test_update_settings(self):
         self.assertTrue(settings.DEBUG)
         args = ['manage.py', 'settings', '--django_debug=False', 'DEBUG']
-        utility = ManagementUtility(argv=args)
+        utility = GlueManagementUtility(argv=args)
         self.begin_capture()
         try:
             utility.execute()
@@ -207,7 +212,7 @@ class CommandLineIntegrationTestCase(ConfigGlueDjangoCommandTestCase):
 
     def test_version_is_printed_once(self):
         args = ['manage.py', '--version']
-        utility = ManagementUtility(argv=args)
+        utility = GlueManagementUtility(argv=args)
         self.begin_capture()
         try:
             utility.execute()
@@ -218,7 +223,7 @@ class CommandLineIntegrationTestCase(ConfigGlueDjangoCommandTestCase):
 
     def test_noargs_doesnt_error(self):
         args = ['manage.py']
-        utility = ManagementUtility(argv=args)
+        utility = GlueManagementUtility(argv=args)
         self.begin_capture()
         try:
             utility.execute()
